@@ -203,7 +203,8 @@ sub ACTION_test {
         $ENV{DYLD_LIBRARY_PATH} = catdir($self->blib,"usrlib");
     }
     elsif ($^O =~ /(?:linux|bsd|sun|sol|dragonfly|hpux|irix)/i) {
-        $ENV{LD_LIBRARY_PATH} = catdir($self->blib,"usrlib");
+        my $oldlibpath = $ENV{LD_LIBRARY_PATH} || '/lib:/usr/lib';
+        $ENV{LD_LIBRARY_PATH} = catdir($self->blib,"usrlib").":$oldlibpath";
      }
     elsif ($^O =~ /aix/i) {
         my $oldlibpath = $ENV{LIBPATH} || '/lib:/usr/lib';
